ass_renderer
==========

A Python library for rendering ASS subtitle file format using libass.

## Installation

```
pip install --user ass-renderer
```

## Contributing

```sh
# Clone the repository:
git clone https://github.com/bubblesub/ass_renderer.git
cd ass_renderer

# Install to a local venv:
uv sync

# Install pre-commit hooks:
uv run pre-commit install

# Run tests:
uv run pytest
```

This project uses uv for packaging.
